#!/bin/bash
# A shell script to delete / drop all tables from MySQL database.
# Usage: ./script user password dbnane
# Usage: ./script user password dbnane server-ip
# Usage: ./script user password dbnane mysql.nixcraft.in
# -------------------------------------------------------------------------
# Copyright (c) 2008 nixCraft project <http://www.cyberciti.biz/fb/>
# This script is licensed under GNU GPL version 2.0 or above
# -------------------------------------------------------------------------
# This script is part of nixCraft shell script collection (NSSC)
# Visit http://bash.cyberciti.biz/ for more information.
# ----------------------------------------------------------------------
# See URL for more info:
# http://www.cyberciti.biz/faq/how-do-i-empty-mysql-database/

# ---------------------------------------------------


if systemctl list-units --type=service --all | grep annode.service; then
    sudo systemctl stop annode.service
fi

MUSER="root"
DB_ROOT_USER_PASS="$1"
MDB="annedb"
 
MHOST="localhost"
 
# Detect paths
MYSQL=$(which mysql)
AWK=$(which awk)
GREP=$(which grep)
 
# help
if [ $# -lt 1 ]
then
    echo "Missing mariadb root user password. Usage:"
    echo "sudo bash droptables.sh yourmariadbrootpassword"
    exit 1
fi
 
# make sure we can connect to server
$MYSQL -u $MUSER -p$DB_ROOT_USER_PASS -h $MHOST -e "use $MDB"  &>/dev/null
if [ $? -ne 0 ]
then
	echo "Error - Cannot connect to mysql server using given username, password or database does not exits!"
	exit 2
fi
 
TABLES=$($MYSQL -u $MUSER -p$DB_ROOT_USER_PASS -h $MHOST $MDB -e 'show tables' | $AWK '{ print $1}' | $GREP -v '^Tables' )
 
# make sure tables exits
if [ "$TABLES" == "" ]
then
	echo "Error - No table found in $MDB database!"
	exit 3
fi
 
# let us do it
for t in $TABLES
do
	echo "Deleting $t table from $MDB database..."
	$MYSQL -u $MUSER -p$DB_ROOT_USER_PASS -h $MHOST $MDB -e "SET FOREIGN_KEY_CHECKS = 0; drop table $t; SET FOREIGN_KEY_CHECKS = 1"	
done

TABLES=$($MYSQL -u $MUSER -p$DB_ROOT_USER_PASS -h $MHOST $MDB -e 'show tables' | $AWK '{ print $1}' | $GREP -v '^Tables' )

for t in $TABLES
do
	echo "Deleting $t view from $MDB database..."
	$MYSQL -u $MUSER -p$DB_ROOT_USER_PASS -h $MHOST $MDB -e "drop view $t;"
	
done


if systemctl list-units --type=service --all | grep annode.service; then
    sudo systemctl start annode.service
fi